#ifndef HX711_h
#define HX711_h

#include <stdint.h>

#define LOADCELL1_CLK_PIN		23
#define LOADCELL1_DATA_PIN	26

// define clock and data pin, channel, and gain factor
// channel selection is made by passing the appropriate gain: 128 or 64 for channel A, 32 for channel B
// gain: 128 or 64 for channel A; channel B works with 32 gain factor only
//HX711(byte dout, byte pd_sck, byte gain = 128);

//400ms wakeup time required prior to a reading
#define HX711_WAKEUP_TIME 400

// Allows to set the pins and gain later than in the constructor
void HX711_begin(uint8_t gain);

// check if HX711 is ready
// from the datasheet: When output data is not ready for retrieval, digital output pin DOUT is high. Serial clock
// input PD_SCK should be low. When DOUT goes to low, it indicates data is ready for retrieval.
uint8_t HX711_is_ready_load1(void);

// set the gain factor; takes effect only after a call to read()
// channel A can be set for a 128 or 64 gain; channel B has a fixed 32 gain
// depending on the parameter, the channel is also set to either A or B
void HX711_set_gain(uint8_t gain);

// waits for the chip to be ready and returns a reading
uint32_t HX711_read_load1(void);

// set OFFSET, the value that's subtracted from the actual reading (tare weight)
void HX711_set_offset(long offset);

// get the current OFFSET
long HX711_get_offset(void);

// puts the chip into power down mode
void HX711_power_down(void);

// wakes up the chip after power down mode
void HX711_power_up(void);


#endif /* HX711_h */
